Installation
============

Stable release
--------------

To install Django Wagtail Feeds, run this command in your terminal:

    $ pip install wagtail_feeds

This is the preferred method to install Django Wagtail Feeds, as it will always install the most recent stable release. If you don't have `pip`_ installed, this `Python installation guide`_ can guide you through the process.

.. _pip: https://pip.pypa.io
.. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/


From Sources
------------

The sources for Django Wagtail Feeds can be downloaded from the `Github repo`_.

You can either clone the public repository:

    $ git clone git://github.com/chrisdev/django-wagtail-feeds

Or download the `tarball`_:

    $ curl  -OL https://github.com/chrisdev/django-wagtail-feeds/tarball/master

Once you have a copy of the source, you can install it with:

    $ python setup.py install


.. _Github repo: https://github.com/chrisdev/wdjango-wagtail-feeds
.. _tarball: https://github.com/chrisdev/django-wagtail-feeds/tarball/master
